/*
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
 with the License.  You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 */

#import <WebKit/WebKit.h>

#ifdef NS_SWIFT_UI_ACTOR
#define CDV_SWIFT_UI_ACTOR NS_SWIFT_UI_ACTOR
#else
#define CDV_SWIFT_UI_ACTOR
#endif

@class CDVViewController;

NS_ASSUME_NONNULL_BEGIN

CDV_SWIFT_UI_ACTOR
@interface CDVWebViewUIDelegate : NSObject <WKUIDelegate>

typedef NS_ENUM(NSInteger, CDVWebViewPermissionGrantType) {
    CDVWebViewPermissionGrantType_Prompt,
    CDVWebViewPermissionGrantType_Deny,
    CDVWebViewPermissionGrantType_Grant,
    CDVWebViewPermissionGrantType_GrantIfSameHost_ElsePrompt,
    CDVWebViewPermissionGrantType_GrantIfSameHost_ElseDeny
};

@property (nonatomic, nullable, copy) NSString* title;
@property (nonatomic, assign) BOOL allowNewWindows;
@property (nonatomic, assign) CDVWebViewPermissionGrantType mediaPermissionGrantType;

- (instancetype)initWithViewController:(CDVViewController*)vc;

@end

NS_ASSUME_NONNULL_END
